<?php

namespace Shopping\Seller\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Seller\Models\SellerBankInfo;

class SellerBankInfoPolicy
{

    /**
     * Determine if the given user can view the seller_bank_info.
     *
     * @param UserPolicy $user
     * @param SellerBankInfo $seller_bank_info
     *
     * @return bool
     */
    public function view(UserPolicy $user, SellerBankInfo $seller_bank_info)
    {
        if ($user->canDo('seller.seller_bank_info.view') && $user->isAdmin()) {
            return true;
        }

        return $seller_bank_info->user_id == user_id() && $seller_bank_info->user_type == user_type();
    }

    /**
     * Determine if the given user can create a seller_bank_info.
     *
     * @param UserPolicy $user
     * @param SellerBankInfo $seller_bank_info
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('seller.seller_bank_info.create');
    }

    /**
     * Determine if the given user can update the given seller_bank_info.
     *
     * @param UserPolicy $user
     * @param SellerBankInfo $seller_bank_info
     *
     * @return bool
     */
    public function update(UserPolicy $user, SellerBankInfo $seller_bank_info)
    {
        if ($user->canDo('seller.seller_bank_info.edit') && $user->isAdmin()) {
            return true;
        }

        return $seller_bank_info->user_id == user_id() && $seller_bank_info->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given seller_bank_info.
     *
     * @param UserPolicy $user
     * @param SellerBankInfo $seller_bank_info
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, SellerBankInfo $seller_bank_info)
    {
        return $seller_bank_info->user_id == user_id() && $seller_bank_info->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given seller_bank_info.
     *
     * @param UserPolicy $user
     * @param SellerBankInfo $seller_bank_info
     *
     * @return bool
     */
    public function verify(UserPolicy $user, SellerBankInfo $seller_bank_info)
    {
        if ($user->canDo('seller.seller_bank_info.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given seller_bank_info.
     *
     * @param UserPolicy $user
     * @param SellerBankInfo $seller_bank_info
     *
     * @return bool
     */
    public function approve(UserPolicy $user, SellerBankInfo $seller_bank_info)
    {
        if ($user->canDo('seller.seller_bank_info.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
